"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var path = require('path');
/*::

type ApiType = {|
  +assertVersion: number => void,
|}

type ExternalOptions = {|
  +target?: 'js' | 'flow',
|}

type BabelRule = string | [string, Object];
type BabelRules = $ReadOnlyArray<BabelRule>;

*/


module.exports = function (api
/*: ApiType */
, externalOptions
/*: ExternalOptions */
) {
  api.assertVersion(7);
  var options = (0, _objectSpread2.default)({
    target: 'js'
  }, externalOptions);
  var presets
  /*: BabelRules */
  = [];
  var plugins
  /*: BabelRules */
  = [];
  var retainLines = false;

  if (options.target === 'flow') {
    plugins = [path.join(__dirname, 'dev-declaration')];
    retainLines = true;
  } else if (options.target === 'js') {
    presets = [['@babel/preset-env', {
      modules: 'commonjs',
      targets: {
        node: 'current',
        browsers: ['last 2 versions', 'ie >= 11'] // https://gitlab.skypicker.com/frontend/frontend/blob/master/webpack.common.js

      } // TODO - loose: true (?)

    }], '@babel/preset-react'];
    plugins = [path.join(__dirname, 'dev-expression.js'), path.join(__dirname, 'kiwicom-js-invariant.js'), path.join(__dirname, 'kiwicom-js-warning.js'), '@babel/plugin-proposal-class-properties', '@babel/plugin-proposal-nullish-coalescing-operator', '@babel/plugin-proposal-object-rest-spread', '@babel/plugin-proposal-optional-chaining', '@babel/plugin-transform-flow-strip-types', // Transform runtime plugin turns common chunks of code into imports. However, this
    // requires `@babel/runtime` dependency thus we are requiring it as well.
    // See: https://babeljs.io/docs/en/babel-plugin-transform-runtime
    '@babel/plugin-transform-runtime', '@kiwicom/babel-plugin-orbit-components'];
  } else {
    throw new Error('options.target must be one of "js" or "flow".');
  }

  return {
    presets: presets,
    plugins: plugins,
    parserOpts: {
      plugins: ['jsx', 'flow', // Enable parsing of (not transpilation) - necessary for Flow target:
      'classProperties', // https://github.com/tc39/proposal-class-public-fields
      'dynamicImport', // https://github.com/tc39/proposal-dynamic-import
      'nullishCoalescingOperator', // https://github.com/babel/proposals/issues/14
      'objectRestSpread', // https://github.com/tc39/proposal-object-rest-spread
      'optionalChaining']
    },
    retainLines: retainLines
  };
};